Learn R Programming

EngrEcon (version 1.0.0)

future_to_annual: Compute annual payment value from future value

future_to_annual calculate annual value from future value using the accumulated amount after years using sinking fund factor (sff)

Description

Compute annual payment value from future value

future_to_annual calculate annual value from future value using the accumulated amount after years using sinking fund factor (sff)

Usage

future_to_annual(i, n, FV)

Value

A

Arguments

i

discount rate in percent per year

n

life span in years

FV

accumulated (future) value

References

Newnan, D. G., Eschenbach, T. G., Lavelle, J. P., & Oxford, N. Y. Engineering Economic Analysis, 14th ed. New York, Oxford University Press, 2020

David, W., & Terry, R. Fundamentals of Engineering Economics and Decision Analysis. Springer Nature, 2012

Examples

Run this code
 
# Result: A = 5737.83
future_to_annual(0.08, 30, 650000)  

Run the code above in your browser using DataLab