Learn R Programming

EngrEcon (version 1.0.0)

om_distribute: Calculate the present value of periodic operations and maintenance costs

om_distribute Distribute periodic present value operations and maintenance costs over a project life span, discount over project, and compute present value

Description

Calculate the present value of periodic operations and maintenance costs

om_distribute Distribute periodic present value operations and maintenance costs over a project life span, discount over project, and compute present value

Usage

om_distribute(i, n, fq, OM)

Value

OM_dist

Arguments

i

discount rate in percent per year

n

life span in years

fq

frequency of cost in years

OM

operation and maintenance cost incurred at each interval in present value

References

Add citation as needed.

Examples

Run this code

#Result is the present value cost of periodic operations and maintenance expenses.
# Result: idc ($) = 8174.547
om_distribute(0.03, 50, 3, 1000)  

Run the code above in your browser using DataLab